"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.S3Mock = void 0;
const typescript_helper_functions_1 = require("typescript-helper-functions");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * S3 Mock class
 */
class S3Mock extends typescript_helper_functions_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mock an AWS.S3.CopyObjectOutput response
         */
        this.CopyObjectOutput = {};
        /**
         * Mock an AWS.S3.CreateBucketOutput response
         */
        this.CreateBucketOutput = {};
        /**
         * Mock an AWS.S3.DeleteBucketOutput response
         * Technically does not exist
         */
        this.DeleteBucketOutput = {};
        /**
         * Mock an AWS.S3.DeleteObjectOutput response
         */
        this.DeleteObjectOutput = {};
        /**
         * Mock an AWS.S3.DeleteObjectsOutput response
         */
        this.DeleteObjectsOutput = {};
        /**
         * Mock an AWS.S3.GetObjectOutput response
         */
        this.GetObjectOutput = { Body: 'mock-body' };
        /**
         * Mocks an AWS.S3.PutOjbectOutput response
         */
        this.PutObjectOutput = {};
    }
    /**
     * Create the S3 mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // copy object response
            copyObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.CopyObjectOutput);
                }),
            },
            // create bucket response
            createBucket: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.CreateBucketOutput);
                }),
            },
            // delete bucket response
            deleteBucket: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteBucketOutput);
                }),
            },
            // delete object response
            deleteObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteObjectOutput);
                }),
            },
            // delete objects response
            deleteObjects: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteObjectsOutput);
                }),
            },
            // get object response
            getObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.GetObjectOutput);
                }),
            },
            // put object response
            putObject: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.PutObjectOutput);
                }),
            },
        };
        // create the functions
        let functions = new AWS.S3();
        functions = {
            copyObject: () => awsResponses.copyObject,
            createBucket: () => awsResponses.createBucket,
            deleteBucket: () => awsResponses.deleteBucket,
            deleteObject: () => awsResponses.deleteObject,
            deleteObjects: () => awsResponses.deleteObjects,
            getObject: () => awsResponses.getObject,
            putObject: () => awsResponses.putObject,
        };
        return functions;
    }
}
exports.S3Mock = S3Mock;
//# sourceMappingURL=mock.js.map